code.manage.automation

Machine-readable incomplete-test reporting for CI and repair workers.

Machine-readable incomplete-test reporting for CI and repair workers.
raw docstring

+config-path+clj

source

+schema-version+clj

source

-mainclj

(-main & [section output policy])

writes the configured section report for CI

writes the configured section report for CI
sourceraw docstring

baseline-diffclj

(baseline-diff baseline-ids findings)

classifies current finding ids against a baseline

classifies current finding ids against a baseline
sourceraw docstring

finding-idclj

(finding-id kind refer)

returns a stable finding id independent of file line numbers

returns a stable finding id independent of file line numbers
sourceraw docstring

incomplete-reportclj

(incomplete-report _target {:keys [section output write-baseline] :as opts})

CLI-facing report writer; returns the report including its exit code

CLI-facing report writer; returns the report including its exit code
sourceraw docstring

load-configclj

(load-config)
(load-config path)

loads and validates the code.manage automation config

loads and validates the code.manage automation config
sourceraw docstring

load-ednclj

(load-edn path fallback)

reads an EDN file, returning the fallback when absent

reads an EDN file, returning the fallback when absent
sourceraw docstring

namespace-findingsclj

(namespace-findings source-ns lookup project)

returns typed missing and TODO findings for one source namespace

returns typed missing and TODO findings for one source namespace
sourceraw docstring

reportclj

(report section)
(report section
        {:keys [config-path baseline-path policy project]
         :or {config-path +config-path+}})

creates a versioned incomplete-test report for one configured section

creates a versioned incomplete-test report for one configured section
sourceraw docstring

section-configclj

(section-config config section)

returns one configured section

returns one configured section
sourceraw docstring

section-namespacesclj

(section-namespaces selector project)

selects source namespaces for a configured section

selects source namespaces for a configured section
sourceraw docstring

sha256clj

(sha256 value)

returns a lowercase SHA-256 digest

returns a lowercase SHA-256 digest
sourceraw docstring

write-baseline!clj

(write-baseline! path section findings)

updates one section in the reviewed baseline

updates one section in the reviewed baseline
sourceraw docstring

write-json!clj

(write-json! path value)

writes a report as pretty JSON

writes a report as pretty JSON
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries