code.manage.unit.factcheck


*meta-tags*clj


*test-forms*clj


child-entriesclj

(child-entries blk)

returns non-void child blocks together with their starting column

returns non-void child blocks together with their starting column
raw docstring

entry-blockclj

(entry-block entry)

entry-colclj

(entry-col entry)

evaluate-fact-opclj

(evaluate-fact-op test-ns fact-id op)

evaluates a compiled fact op and returns its value

evaluates a compiled fact op and returns its value
raw docstring

fact-block-dataclj

(fact-block-data form)

returns the logical structure of a fact form

returns the logical structure of a fact form
raw docstring

fact-block?clj

(fact-block? blk)

checks if a block is a fact form

checks if a block is a fact form
raw docstring

fact-lineclj

(fact-line entry)

returns the row where the inner fact form starts

returns the row where the inner fact form starts
raw docstring

fact-op-formclj

(fact-op-form op)

returns the input form for a compiled fact op

returns the input form for a compiled fact op
raw docstring

fact-result-valuesclj

(fact-result-values fpkg)

evaluates every compiled op in a fact and returns the raw values

evaluates every compiled op in a fact and returns the raw values
raw docstring

fact-results-mapclj

(fact-results-map test-ns)

evaluates all loaded facts in a namespace and indexes them by line

evaluates all loaded facts in a namespace and indexes them by line
raw docstring

factcheck-generateclj

(factcheck-generate ns params lookup {:keys [root] :as project})

loads a test namespace, evaluates fact forms and regenerates => expectations

loads a test namespace, evaluates fact forms and regenerates `=>` expectations
raw docstring

factcheck-generate-form-stringclj

(factcheck-generate-form-string form values)

generates => expectations for a single fact form

generates `=>` expectations for a single fact form
raw docstring

factcheck-generate-stringclj

(factcheck-generate-string original line->values)

generates => expectations for all top level facts in a file

generates `=>` expectations for all top level facts in a file
raw docstring

factcheck-removeclj

(factcheck-remove ns params lookup project)

removes => expectations from fact tests

removes `=>` expectations from fact tests
raw docstring

factcheck-remove-form-stringclj

(factcheck-remove-form-string form)

removes => expectations from a single fact form

removes `=>` expectations from a single fact form
raw docstring

factcheck-remove-stringclj

(factcheck-remove-string original)

removes => expectations from all top level facts in a file

removes `=>` expectations from all top level facts in a file
raw docstring

leading-indentclj

(leading-indent line)

normalise-block-stringclj

(normalise-block-string s)
(normalise-block-string s indent)

parse-bodyclj

(parse-body blocks)

partitions fact body blocks into plain forms and expression/check pairs

partitions fact body blocks into plain forms and expression/check pairs
raw docstring

render-checkless-itemclj

(render-checkless-item {:keys [expr]})

renders a fact item without an expectation

renders a fact item without an expectation
raw docstring

render-factclj

(render-fact form rendered-items)

renders a fact using already formatted body items

renders a fact using already formatted body items
raw docstring

render-formclj

(render-form form)

formats an arbitrary block or form

formats an arbitrary block or form
raw docstring

render-generated-itemclj

(render-generated-item item value)

renders a fact item with a generated expectation

renders a fact item with a generated expectation
raw docstring

result-stringclj

(result-string value)

renders an evaluation result as an EDN string

renders an evaluation result as an EDN string
raw docstring

top-level-entriesclj

(top-level-entries s)

returns all top level blocks with line info

returns all top level blocks with line info
raw docstring

trim-indentclj

(trim-indent line n)

unwrap-fact-blockclj

(unwrap-fact-block blk)

returns the exact metadata prefix and inner fact block

returns the exact metadata prefix and inner fact block
raw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries