code.manage.unit.import


analyseclj

(analyse ns params lookup project)
source

analyse-fact-testsclj

(analyse-fact-tests nav)
source

analyse-test-codeclj

(analyse-test-code s)
source

arrow-block?clj

(arrow-block? blk)
source

examples-configclj

(examples-config mta)

Parses :examples metadata into a selection map.

Parses `:examples` metadata into a selection map.
sourceraw docstring

find-example-endclj

(find-example-end blocks expr-idx)
source

gather-factclj

(gather-fact nav)
source

gather-fact-bodyclj

(gather-fact-body nav mta)
source

gather-selected-fact-bodyclj

(gather-selected-fact-body nav mta)

Builds a filtered fact body using :examples metadata.

Builds a filtered fact body using `:examples` metadata.
sourceraw docstring

importclj

(import ns params lookup project)

imports unit test docstrings, with optional example body selection

imports unit test docstrings, with optional example body selection
sourceraw docstring

next-significant-indexclj

(next-significant-index blocks start)
source

significant-block?clj

(significant-block? blk)
source

strip-checkclj

(strip-check blocks)
source

trim-right-voidclj

(trim-right-void blocks)
source

cljdoc builds & hosts documentation for Clojure/Script libraries