code.manage.unit.isolate


*meta-tags*clj

source

*test-forms*clj

source

arrow-entry?clj

(arrow-entry? entry)
source

body-entriesclj

(body-entries blk row-base)

returns all child entries of a fact block, including whitespace

returns all child entries of a fact block, including whitespace
sourceraw docstring

entry-matches-line?clj

(entry-matches-line? {:keys [line]} target-lines)

checks if an entry spans any of the target lines

checks if an entry spans any of the target lines
sourceraw docstring

example-rangesclj

(example-ranges entries)

returns body ranges for individual fact examples

returns body ranges for individual fact examples
sourceraw docstring

fact-block?clj

(fact-block? blk)

checks if a block is a fact form

checks if a block is a fact form
sourceraw docstring

fact-body-entriesclj

(fact-body-entries entry)

returns the operator, optional intro, and body entries for a fact

returns the operator, optional intro, and body entries for a fact
sourceraw docstring

failing-entriesclj

(failing-entries run-data ns)

returns failing run entries for a test namespace

returns failing run entries for a test namespace
sourceraw docstring

failure-functionclj

(failure-function entry)

returns the preferred function identifier for a failing entry

returns the preferred function identifier for a failing entry
sourceraw docstring

failure-functionsclj

(failure-functions entries)

returns unique failure identifiers in encounter order

returns unique failure identifiers in encounter order
sourceraw docstring

failure-lineclj

(failure-line entry)

normalises a failure line entry into a row number

normalises a failure line entry into a row number
sourceraw docstring

find-example-endclj

(find-example-end entries expr-idx)
source

isolateclj

(isolate ns {:keys [run suffix write] :as params} lookup project)

copies failing facts from a run report into a new test namespace

(code.manage.unit.isolate/isolate 'xt.lang.spec-base-test {:run ".lang/runs/run-1776913569354.edn" :suffix "-fix" :write false} lookup project)

copies failing facts from a run report into a new test namespace

(code.manage.unit.isolate/isolate
  'xt.lang.spec-base-test
  {:run ".lang/runs/run-1776913569354.edn"
   :suffix "-fix"
   :write false}
  lookup
  project)
sourceraw docstring

isolate-fact-stringclj

(isolate-fact-string entry target-lines)

returns a fact string containing only the selected examples

returns a fact string containing only the selected examples
sourceraw docstring

isolate-stringclj

(isolate-string original target-ns target-lines)

returns a test file containing only the selected failing checks

returns a test file containing only the selected failing checks
sourceraw docstring

isolate-target-nsclj

(isolate-target-ns ns)
(isolate-target-ns ns suffix)

returns the target namespace for isolated tests

returns the target namespace for isolated tests
sourceraw docstring

latest-run-fileclj

(latest-run-file root)

returns the most recent .lang/runs/run-*.edn file

returns the most recent `.lang/runs/run-*.edn` file
sourceraw docstring

next-significant-indexclj

(next-significant-index entries start)
source

ns-block?clj

(ns-block? blk)

checks if a block is an ns form

checks if a block is an ns form
sourceraw docstring

parse-run-stringclj

(parse-run-string s)

parses a run report, preserving legacy #error payloads as plain maps

parses a run report, preserving legacy `#error` payloads as plain maps
sourceraw docstring

read-run-fileclj

(read-run-file path)

reads a saved run report

reads a saved run report
sourceraw docstring

rewrite-ns-formclj

(rewrite-ns-form blk target-ns)

rewrites the namespace symbol for an ns form

rewrites the namespace symbol for an ns form
sourceraw docstring

sanitize-run-stringclj

(sanitize-run-string s)

quotes legacy unreadable printed objects so the report can be parsed as EDN

quotes legacy unreadable printed objects so the report can be parsed as EDN
sourceraw docstring

selected-fact-bodyclj

(selected-fact-body entries target-lines intro?)

returns a body string for the selected failing examples within a fact

returns a body string for the selected failing examples within a fact
sourceraw docstring

significant-entry?clj

(significant-entry? entry)
source

top-level-entriesclj

(top-level-entries s)

returns top level blocks with their line ranges

returns top level blocks with their line ranges
sourceraw docstring

trim-right-voidclj

(trim-right-void entries)
source

unwrap-fact-blockclj

(unwrap-fact-block blk)

returns the exact metadata prefix and inner fact block

returns the exact metadata prefix and inner fact block
sourceraw docstring

unwrap-meta-blockclj

(unwrap-meta-block blk)

returns the inner expression for metadata-wrapped blocks

returns the inner expression for metadata-wrapped blocks
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries