(child-entries block)returns non-void child blocks together with their starting column
returns non-void child blocks together with their starting column
(entry-block entry)returns the block for an entry
returns the block for an entry
(entry-col entry)returns the starting column for an entry
returns the starting column for an entry
(fact-block? block)checks if a block is a fact form, preserving reader/block structure
checks if a block is a fact form, preserving reader/block structure
(form-op block)returns the top-level operator of a list form
returns the top-level operator of a list form
(leading-indent line)counts leading spaces and tabs in a line
counts leading spaces and tabs in a line
(normalise-block-string s)(normalise-block-string s indent)removes the parent indentation from the rest of a block string
removes the parent indentation from the rest of a block string
(ns-block? block)checks if a block is an ns form
checks if a block is an ns form
(parse-body blocks)partitions fact body blocks into plain forms and expression/check pairs
partitions fact body blocks into plain forms and expression/check pairs
(parse-map-pairs entries)partitions map entries into key/value pairs
partitions map entries into key/value pairs
(render-form form)formats an arbitrary block or form
formats an arbitrary block or form
(render-item {:keys [type expr expected]})formats a plain form or expression/check pair
formats a plain form or expression/check pair
(render-ns-clause form)formats a single ns clause
formats a single ns clause
(render-prefixed-items prefix items suffix separator)(render-prefixed-items prefix items suffix separator render-item-fn)renders items with aligned continuation
renders items with aligned continuation
(render-script-map form)formats a script config map
formats a script config map
(render-script-map-pair key value prefix-indent)formats a single script option
formats a single script option
(render-script-value key-entry value-entry)formats a script option value
formats a script option value
(script-block? block)checks if a block is an l/script* form
checks if a block is an l/script* form
(script-option-rank entry)returns the sort rank for a script option
returns the sort rank for a script option
(snap-block-string node)formats supported top-level blocks into snap-to layout
formats supported top-level blocks into snap-to layout
(snap-form-string form)formats a single fact form into snap-to layout
formats a single fact form into snap-to layout
(snap-ns-string form)formats a single ns form into snap-to layout
formats a single ns form into snap-to layout
(snap-script-string form)formats a single l/script* form into snap-to layout
formats a single l/script* form into snap-to layout
(snapto ns params lookup project)formats fact tests into a consistent snap-to layout
(project/in-context (snapto {:write false})) => map?
formats fact tests into a consistent snap-to layout
(project/in-context (snapto {:write false}))
=> map?(snapto-string original)formats supported top-level forms in a file
formats supported top-level forms in a file
(trim-indent line n)removes up to n leading spaces/tabs from a line
removes up to n leading spaces/tabs from a line
(unwrap-fact-block block)returns the exact metadata prefix and inner block
returns the exact metadata prefix and inner block
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |