Machine-readable incomplete-test reporting for CI and repair workers.
Machine-readable incomplete-test reporting for CI and repair workers.
(-main & [section output policy])writes the configured section report for CI
writes the configured section report for CI
(baseline-diff baseline-ids findings)classifies current finding ids against a baseline
classifies current finding ids against a baseline
(finding-id kind refer)returns a stable finding id independent of file line numbers
returns a stable finding id independent of file line numbers
(incomplete-report _target {:keys [section output write-baseline] :as opts})CLI-facing report writer; returns the report including its exit code
CLI-facing report writer; returns the report including its exit code
(load-config)(load-config path)loads and validates the code.manage automation config
loads and validates the code.manage automation config
(load-edn path fallback)reads an EDN file, returning the fallback when absent
reads an EDN file, returning the fallback when absent
(namespace-findings source-ns lookup project)returns typed missing and TODO findings for one source namespace
returns typed missing and TODO findings for one source namespace
(report section)(report section
{:keys [config-path baseline-path policy project]
:or {config-path +config-path+}})creates a versioned incomplete-test report for one configured section
creates a versioned incomplete-test report for one configured section
(section-config config section)returns one configured section
returns one configured section
(section-namespaces selector project)selects source namespaces for a configured section
selects source namespaces for a configured section
(sha256 value)returns a lowercase SHA-256 digest
returns a lowercase SHA-256 digest
(write-baseline! path section findings)updates one section in the reviewed baseline
updates one section in the reviewed baseline
(write-json! path value)writes a report as pretty JSON
writes a report as pretty JSON
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |