(child-entries blk)returns non-void child blocks together with their starting column
returns non-void child blocks together with their starting column
(entry-block entry)(entry-col entry)(evaluate-fact-op test-ns fact-id op)evaluates a compiled fact op and returns its value
evaluates a compiled fact op and returns its value
(fact-block-data form)returns the logical structure of a fact form
returns the logical structure of a fact form
(fact-block? blk)checks if a block is a fact form
checks if a block is a fact form
(fact-line entry)returns the row where the inner fact form starts
returns the row where the inner fact form starts
(fact-op-form op)returns the input form for a compiled fact op
returns the input form for a compiled fact op
(fact-result-values fpkg)evaluates every compiled op in a fact and returns the raw values
evaluates every compiled op in a fact and returns the raw values
(fact-results-map test-ns)evaluates all loaded facts in a namespace and indexes them by line
evaluates all loaded facts in a namespace and indexes them by line
(factcheck-generate ns params lookup {:keys [root] :as project})loads a test namespace, evaluates fact forms and regenerates => expectations
loads a test namespace, evaluates fact forms and regenerates `=>` expectations
(factcheck-generate-form-string form values)generates => expectations for a single fact form
generates `=>` expectations for a single fact form
(factcheck-generate-string original line->values)generates => expectations for all top level facts in a file
generates `=>` expectations for all top level facts in a file
(factcheck-remove ns params lookup project)removes => expectations from fact tests
removes `=>` expectations from fact tests
(factcheck-remove-form-string form)removes => expectations from a single fact form
removes `=>` expectations from a single fact form
(factcheck-remove-string original)removes => expectations from all top level facts in a file
removes `=>` expectations from all top level facts in a file
(leading-indent line)(normalise-block-string s)(normalise-block-string s indent)(parse-body blocks)partitions fact body blocks into plain forms and expression/check pairs
partitions fact body blocks into plain forms and expression/check pairs
(render-checkless-item {:keys [expr]})renders a fact item without an expectation
renders a fact item without an expectation
(render-fact form rendered-items)renders a fact using already formatted body items
renders a fact using already formatted body items
(render-form form)formats an arbitrary block or form
formats an arbitrary block or form
(render-generated-item item value)renders a fact item with a generated expectation
renders a fact item with a generated expectation
(result-string value)renders an evaluation result as an EDN string
renders an evaluation result as an EDN string
(top-level-entries s)returns all top level blocks with line info
returns all top level blocks with line info
(trim-indent line n)(unwrap-fact-block blk)returns the exact metadata prefix and inner fact block
returns the exact metadata prefix and inner fact block
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |