code.manage.unit.import


analyseclj

(analyse ns params lookup project)

analyse-fact-testsclj

(analyse-fact-tests nav)

analyse-test-codeclj

(analyse-test-code s)

arrow-block?clj

(arrow-block? blk)

examples-configclj

(examples-config mta)

Parses :examples metadata into a selection map.

Parses `:examples` metadata into a selection map.
raw docstring

find-example-endclj

(find-example-end blocks expr-idx)

gather-factclj

(gather-fact nav)

gather-fact-bodyclj

(gather-fact-body nav mta)

gather-selected-fact-bodyclj

(gather-selected-fact-body nav mta)

Builds a filtered fact body using :examples metadata.

Builds a filtered fact body using `:examples` metadata.
raw docstring

importclj

(import ns params lookup project)

imports unit test docstrings, with optional example body selection

imports unit test docstrings, with optional example body selection
raw docstring

next-significant-indexclj

(next-significant-index blocks start)

significant-block?clj

(significant-block? blk)

strip-checkclj

(strip-check blocks)

trim-right-voidclj

(trim-right-void blocks)

cljdoc builds & hosts documentation for Clojure/Script libraries