(analyse ns params lookup project)(analyse-fact-tests nav)(analyse-test-code s)(arrow-block? blk)(examples-config mta)Parses :examples metadata into a selection map.
Parses `:examples` metadata into a selection map.
(find-example-end blocks expr-idx)(gather-fact nav)(gather-fact-body nav mta)(gather-selected-fact-body nav mta)Builds a filtered fact body using :examples metadata.
Builds a filtered fact body using `:examples` metadata.
(import ns params lookup project)imports unit test docstrings, with optional example body selection
imports unit test docstrings, with optional example body selection
(next-significant-index blocks start)(significant-block? blk)(strip-check blocks)(trim-right-void blocks)cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |