code.manage.unit.isolate


*meta-tags*clj


*test-forms*clj


arrow-entry?clj

(arrow-entry? entry)

body-entriesclj

(body-entries blk row-base)

returns all child entries of a fact block, including whitespace

returns all child entries of a fact block, including whitespace
raw docstring

entry-matches-line?clj

(entry-matches-line? {:keys [line]} target-lines)

checks if an entry spans any of the target lines

checks if an entry spans any of the target lines
raw docstring

example-rangesclj

(example-ranges entries)

returns body ranges for individual fact examples

returns body ranges for individual fact examples
raw docstring

fact-block?clj

(fact-block? blk)

checks if a block is a fact form

checks if a block is a fact form
raw docstring

fact-body-entriesclj

(fact-body-entries entry)

returns the operator, optional intro, and body entries for a fact

returns the operator, optional intro, and body entries for a fact
raw docstring

failing-entriesclj

(failing-entries run-data ns)

returns failing run entries for a test namespace

returns failing run entries for a test namespace
raw docstring

failure-functionclj

(failure-function entry)

returns the preferred function identifier for a failing entry

returns the preferred function identifier for a failing entry
raw docstring

failure-functionsclj

(failure-functions entries)

returns unique failure identifiers in encounter order

returns unique failure identifiers in encounter order
raw docstring

failure-lineclj

(failure-line entry)

normalises a failure line entry into a row number

normalises a failure line entry into a row number
raw docstring

find-example-endclj

(find-example-end entries expr-idx)

isolateclj

(isolate ns {:keys [run suffix write] :as params} lookup project)

copies failing facts from a run report into a new test namespace

(code.manage.unit.isolate/isolate 'xt.lang.spec-base-test {:run ".hara/runs/run-1776913569354.edn" :suffix "-fix" :write false} lookup project)

copies failing facts from a run report into a new test namespace

(code.manage.unit.isolate/isolate
  'xt.lang.spec-base-test
  {:run ".hara/runs/run-1776913569354.edn"
   :suffix "-fix"
   :write false}
  lookup
  project)
raw docstring

isolate-fact-stringclj

(isolate-fact-string entry target-lines)

returns a fact string containing only the selected examples

returns a fact string containing only the selected examples
raw docstring

isolate-stringclj

(isolate-string original target-ns target-lines)

returns a test file containing only the selected failing checks

returns a test file containing only the selected failing checks
raw docstring

isolate-target-nsclj

(isolate-target-ns ns)
(isolate-target-ns ns suffix)

returns the target namespace for isolated tests

returns the target namespace for isolated tests
raw docstring

latest-run-fileclj

(latest-run-file root)

returns the most recent .hara/runs/run-*.edn file

returns the most recent `.hara/runs/run-*.edn` file
raw docstring

next-significant-indexclj

(next-significant-index entries start)

ns-block?clj

(ns-block? blk)

checks if a block is an ns form

checks if a block is an ns form
raw docstring

parse-run-stringclj

(parse-run-string s)

parses a run report, preserving legacy #error payloads as plain maps

parses a run report, preserving legacy `#error` payloads as plain maps
raw docstring

read-run-fileclj

(read-run-file path)

reads a saved run report

reads a saved run report
raw docstring

rewrite-ns-formclj

(rewrite-ns-form blk target-ns)

rewrites the namespace symbol for an ns form

rewrites the namespace symbol for an ns form
raw docstring

sanitize-run-stringclj

(sanitize-run-string s)

quotes legacy unreadable printed objects so the report can be parsed as EDN

quotes legacy unreadable printed objects so the report can be parsed as EDN
raw docstring

selected-fact-bodyclj

(selected-fact-body entries target-lines intro?)

returns a body string for the selected failing examples within a fact

returns a body string for the selected failing examples within a fact
raw docstring

significant-entry?clj

(significant-entry? entry)

top-level-entriesclj

(top-level-entries s)

returns top level blocks with their line ranges

returns top level blocks with their line ranges
raw docstring

trim-right-voidclj

(trim-right-void entries)

unwrap-fact-blockclj

(unwrap-fact-block blk)

returns the exact metadata prefix and inner fact block

returns the exact metadata prefix and inner fact block
raw docstring

unwrap-meta-blockclj

(unwrap-meta-block blk)

returns the inner expression for metadata-wrapped blocks

returns the inner expression for metadata-wrapped blocks
raw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries